Solve chance constrained radial super-efficiency DEA models, based on the
Cooper et al. (2002) chance constrained radial efficiency models. Analogously to the deterministic case,
it removes the evaluated DMU from the set of reference DMUs dmu_ref
with respect to which it is evaluated.
modelstoch_radial_supereff(datadea,
dmu_eval = NULL,
dmu_ref = NULL,
...)A list with the results for the evaluated DMUs and other parameters for reproducibility.
The data of class deadata_stoch with the expected values
of inputs and outputs.
A numeric vector containing which DMUs have to be evaluated.
If NULL (default), all DMUs are considered.
A numeric vector containing which DMUs are the evaluation reference set.
If NULL (default), all DMUs are considered.
Model parameters like orientation or rts, and other
parameters to be passed to the solver.
Vicente Bolós (vicente.bolos@uv.es). Department of Business Mathematics
Rafael Benítez (rafael.suarez@uv.es). Department of Business Mathematics
Vicente Coll-Serrano (vicente.coll@uv.es). Quantitative Methods for Measuring Culture (MC2). Applied Economics.
University of Valencia (Spain)
Cooper, W.W.; Deng, H.; Huang, Z.; Li, S.X. (2002). “Chance constrained programming approaches to technical efficiencies and inefficiencies in stochastic data envelopment analysis", Journal of the Operational Research Society, 53:12, 1347-1356.
modelstoch_radial